<?php

    class Reactor_Script_Exit_Code_Condition extends Reactor_Condition
    {
        protected $tpl = 'reactor_script_exit_code.php';
        protected $name = 'Script exit code is';
		
		public static $registration = array(
			CONDITION_NAME => 'Check a Nagios Reactor script exit code',
			CONDITION_CATEGORY => 'Nagios Reactor',
			CONDITION_DESCRIPTION => 'Check the return code of an installed Reactor script',
			CONDITION_AUTHOR => 'Ethan Galstad Mike Guthrie, Nagios Enterprises, LLC',
			CONDITION_VERSION => '1.0',
			CONDITION_DATE => '02/28/2013', //Last version update
			CONDITION_AUTHLEVEL => 0,  // 0 - everyone | 1 - Admin only
			CONDITION_TYPE => 'core', //core | user. core modules can't be deleted
			CONDITION_META => array('script_output','script_return_code'),	//Misc information	
		); 			
		
        protected $fields = array(
            'plugin' => array(
                'label' => 'plugin',
                'validate' => 'trim|required|callback_valid_reactor_script',
            ),
            'args' => array(
                'label' => 'args',
                'validate' => '',
            ),	
            'operator' => array(
                'label' => 'operator',
                'validate' => 'xss_clean|required',
            ),	
            'code' => array(
                'label' => 'code',
                'validate' => 'trim|numeric|required',
            ),			
        );

        public function get_label()
        {
            if($params = $this->get_params()) {
                $operator=$params['operator'];
                $ostr="";
                switch($operator){
                    case "eq":
                        $ostr="equal to";
                        break;
                    case "gt":
                        $ostr="greater than";
                        break;
                    case "lt":
                        $ostr="less than";
                        break;
                    default:
                        break;
                    }
                if(isset($params['plugin'],$params['operator'],$params['code'])) 
                    return sprintf('Reactor script \'%s\' exit code is %s \'%s\'', $params['plugin'],$ostr,$params['code']);
            }
            
            return parent::get_label();
		}
        
		public function valid_reactor_script($file) {
			$fullpath = realpath(APPPATH).'/libraries/scripts/'.$file;
			if(file_exists($fullpath) && is_executable($fullpath))
				return true;
			else
				return false;
		}
       
        public function run($context)
        {									
            $this->set_context($context);
            $params = $this->get_params();
			
			$plugin = $params['plugin'];
			$op = $params['operator']; 
			$args = $params['args'];
			$code = intval($params['code']); 
			
			if(ENVIRONMENT=='development')
				logit("Running reactor script...".print_r($params,true));
			
			$fullpath = realpath(APPPATH).'/libraries/scripts/'.$plugin;
			$cmd = $fullpath.' '.escapeshellcmd($args);
			if(ENVIRONMENT=='development')
				logit("Running CMD: {$cmd}");

			$line = exec($cmd,$arr,$returncode);

			if(ENVIRONMENT=='development')
				logit("Results...".print_r($arr,true)."\nCODE: {$returncode}");			
			
			$this->set_context_var('script_output',implode("\n",$arr));
            $this->set_context_var('script_return_code',$returncode);
						
			$result = false; 
						
			if($op=='eq' && $code==$returncode) 
				$result = true;			
			if($op=='lt' && $returncode < $code) 
				$result = true;			
			if($op=='gt' && $returncode > $code) 
				$result = true;
			
			$this->set_result($result); 
        }
	
	}
